==> drumgizmo-0.9.3.tar.gz: drumgizmo-0.9.3/dgedit/dgedit_qrc.cpp <==
/****************************************************************************
** Resource object code
**
** Created: Fri May 3 18:57:24 2013
**      by: The Resource Compiler for Qt version 4.8.4
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /mnt/solar/docs/deva/c/drumgizmo/dgedit/icons/master.png
  0x0,0x0,0x1,0x1c,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x1,0x73,0x52,0x47,0x42,0x0,0xae,0xce,0x1c,0xe9,0x0,0x0,0x0,
  0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,0xa7,0x93,0x0,
  0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,0xb,0x13,0x1,
  0x0,0x9a,0x9c,0x18,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xd9,0xc,0x19,
  0xb,0x22,0x29,0xf8,0x51,0x23,0xfe,0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x43,
  0x6f,0x6d,0x6d,0x65,0x6e,0x74,0x0,0x43,0x72,0x65,0x61,0x74,0x65,0x64,0x20,0x77,
  0x69,0x74,0x68,0x20,0x47,0x49,0x4d,0x50,0x57,0x81,0xe,0x17,0x0,0x0,0x0,0x77,
  0x49,0x44,0x41,0x54,0x38,0xcb,0x63,0x60,0x18,0x5,0x30,0xf0,0x1f,0x8a,0xf9,0x19,
  0x18,0x18,0x16,0x30,0x30,0x30,0x7c,0x64,0x60,0x60,0x78,0xc3,0xc0,0xc0,0x50,0x6,
  0x95,0x17,0x65,0x60,0x60,0x58,0xc9,0xc0,0xc0,0xf0,0x5,0x2a,0xde,0xca,0xc0,0xc0,
  0xc0,0x88,0xcd,0x80,0x4d,0x48,0x6c,0x18,0xe,0x65,0x60,0x60,0x38,0x83,0x45,0x3c,
  0x1d,0x9b,0x1,0xa7,0x18,0x18,0x18,0xd4,0x19,0x18,0x18,0x38,0x19,0x18,0x18,0xfa,
  0xa0,0x62,0x9f,0x70,0x88,0x9f,0xc4,0x66,0x80,0x21,0x92,0x98,0x28,0x1,0xf1,0xcf,
  0xd8,0xc,0x60,0xc6,0x11,0x36,0xb8,0xc4,0x71,0xb,0x10,0x2b,0xce,0x44,0x69,0xf4,
  0xd,0x3,0x3,0x6,0x1e,0x0,0x0,0xb0,0xee,0x2f,0x98,0x84,0xc6,0x4,0x1,0x0,
  0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
    // /mnt/solar/docs/deva/c/drumgizmo/dgedit/icons/file.png
  0x0,0x0,0x0,0xb7,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x1,0x73,0x52,0x47,0x42,0x0,0xae,0xce,0x1c,0xe9,0x0,0x0,0x0,
  0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,0xa7,0x93,0x0,
  0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,0xb,0x13,0x1,
  0x0,0x9a,0x9c,0x18,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xd9,0xc,0x19,
  0xb,0x22,0xa,0x5a,0x36,0x52,0x8c,0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x43,
  0x6f,0x6d,0x6d,0x65,0x6e,0x74,0x0,0x43,0x72,0x65,0x61,0x74,0x65,0x64,0x20,0x77,
  0x69,0x74,0x68,0x20,0x47,0x49,0x4d,0x50,0x57,0x81,0xe,0x17,0x0,0x0,0x0,0x12,
  0x49,0x44,0x41,0x54,0x38,0xcb,0x63,0x60,0x18,0x5,0xa3,0x60,0x14,0x8c,0x2,0x8,
  0x0,0x0,0x4,0x10,0x0,0x1,0x85,0x3f,0xaa,0x72,0x0,0x0,0x0,0x0,0x49,0x45,
  0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // master.png
  0x0,0xa,
  0xa,0xcb,0x26,0x7,
  0x0,0x6d,
  0x0,0x61,0x0,0x73,0x0,0x74,0x0,0x65,0x0,0x72,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
    // file.png
  0x0,0x8,
  0x0,0x28,0x5a,0xe7,
  0x0,0x66,
  0x0,0x69,0x0,0x6c,0x0,0x65,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,
  // :/icons/file.png
  0x0,0x0,0x0,0x2a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x1,0x20,
  // :/icons/master.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources))

int QT_MANGLE_NAMESPACE(qCleanupResources)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources))

==> drumgizmo-0.9.4.tar.gz: drumgizmo-0.9.4/dgedit/dgedit_qrc.cpp <==
/****************************************************************************
** Resource object code
**
** Created: Wed Mar 5 21:14:07 2014
**      by: The Resource Compiler for Qt version 4.8.4
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /home/deva/tmp/drumgizmo-0.9.4/dgedit/icons/master.png
  0x0,0x0,0x1,0x1c,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x1,0x73,0x52,0x47,0x42,0x0,0xae,0xce,0x1c,0xe9,0x0,0x0,0x0,
  0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,0xa7,0x93,0x0,
  0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,0xb,0x13,0x1,
  0x0,0x9a,0x9c,0x18,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xd9,0xc,0x19,
  0xb,0x22,0x29,0xf8,0x51,0x23,0xfe,0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x43,
  0x6f,0x6d,0x6d,0x65,0x6e,0x74,0x0,0x43,0x72,0x65,0x61,0x74,0x65,0x64,0x20,0x77,
  0x69,0x74,0x68,0x20,0x47,0x49,0x4d,0x50,0x57,0x81,0xe,0x17,0x0,0x0,0x0,0x77,
  0x49,0x44,0x41,0x54,0x38,0xcb,0x63,0x60,0x18,0x5,0x30,0xf0,0x1f,0x8a,0xf9,0x19,
  0x18,0x18,0x16,0x30,0x30,0x30,0x7c,0x64,0x60,0x60,0x78,0xc3,0xc0,0xc0,0x50,0x6,
  0x95,0x17,0x65,0x60,0x60,0x58,0xc9,0xc0,0xc0,0xf0,0x5,0x2a,0xde,0xca,0xc0,0xc0,
  0xc0,0x88,0xcd,0x80,0x4d,0x48,0x6c,0x18,0xe,0x65,0x60,0x60,0x38,0x83,0x45,0x3c,
  0x1d,0x9b,0x1,0xa7,0x18,0x18,0x18,0xd4,0x19,0x18,0x18,0x38,0x19,0x18,0x18,0xfa,
  0xa0,0x62,0x9f,0x70,0x88,0x9f,0xc4,0x66,0x80,0x21,0x92,0x98,0x28,0x1,0xf1,0xcf,
  0xd8,0xc,0x60,0xc6,0x11,0x36,0xb8,0xc4,0x71,0xb,0x10,0x2b,0xce,0x44,0x69,0xf4,
  0xd,0x3,0x3,0x6,0x1e,0x0,0x0,0xb0,0xee,0x2f,0x98,0x84,0xc6,0x4,0x1,0x0,
  0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
    // /home/deva/tmp/drumgizmo-0.9.4/dgedit/icons/file.png
  0x0,0x0,0x0,0xb7,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x1,0x73,0x52,0x47,0x42,0x0,0xae,0xce,0x1c,0xe9,0x0,0x0,0x0,
  0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,0xa7,0x93,0x0,
  0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,0xb,0x13,0x1,
  0x0,0x9a,0x9c,0x18,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,0xd9,0xc,0x19,
  0xb,0x22,0xa,0x5a,0x36,0x52,0x8c,0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x43,
  0x6f,0x6d,0x6d,0x65,0x6e,0x74,0x0,0x43,0x72,0x65,0x61,0x74,0x65,0x64,0x20,0x77,
  0x69,0x74,0x68,0x20,0x47,0x49,0x4d,0x50,0x57,0x81,0xe,0x17,0x0,0x0,0x0,0x12,
  0x49,0x44,0x41,0x54,0x38,0xcb,0x63,0x60,0x18,0x5,0xa3,0x60,0x14,0x8c,0x2,0x8,
  0x0,0x0,0x4,0x10,0x0,0x1,0x85,0x3f,0xaa,0x72,0x0,0x0,0x0,0x0,0x49,0x45,
  0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // master.png
  0x0,0xa,
  0xa,0xcb,0x26,0x7,
  0x0,0x6d,
  0x0,0x61,0x0,0x73,0x0,0x74,0x0,0x65,0x0,0x72,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
    // file.png
  0x0,0x8,
  0x0,0x28,0x5a,0xe7,
  0x0,0x66,
  0x0,0x69,0x0,0x6c,0x0,0x65,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,
  // :/icons/file.png
  0x0,0x0,0x0,0x2a,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x1,0x20,
  // :/icons/master.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources))

int QT_MANGLE_NAMESPACE(qCleanupResources)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources))
